/*
 * Test for timestamp
 */
import java.sql.*;

public class Timestamp extends PgpoolTest {
    public void do_test() throws SQLException {

	try {
	    ResultSet rs;
	    PreparedStatement pstmt = null;
	    Statement stmt = null;

	    connection.setAutoCommit(false);

	    pstmt = connection.prepareStatement("CREATE TEMP TABLE t1(i INTEGER, t timestamp)");
	    pstmt.executeUpdate();
	    pstmt.close();

	    pstmt = connection.prepareStatement("INSERT INTO t1(i,t) VALUES(?,CURRENT_TIMESTAMP)");
	    pstmt.setInt(1, 100);
	    pstmt.executeUpdate();
	    pstmt.close();

	    pstmt = connection.prepareStatement("SELECT * FROM t1");
	    pstmt.executeQuery();
	    pstmt.close();

	    connection.commit();
	}
	finally {
	    connection.close();
	    logwriter.close();
	}
    }

    public String getTestName() {
	return "Timestamp";
    }
}
